library(tidyverse)
library(stringi)
library(readxl)
library(DescTools)

#"T:/Imaging/AG_Hecht_ceAngio/analysisZuerich_20181109/data_results/"

files <- list.files(path="data/vessel_tracing_raw/", pattern="*.txt",full.names=TRUE, recursive=TRUE)

for(i in 1:85) {
  
    #data extracting 1
    my_data <- read.delim(files[i], skip = 7)
    
    #data extracting 2
    my_data2 <- read.delim(files[i], skip = 1)
    my_data2 <- my_data2 %>%
      slice(1)%>%
      separate(NVessels........NVesselPixel..........NMaskPixel...........threshold...............limit.............maximum,c("1","2","3","4","5","6"))%>%
      select(4:5)%>%
      unite(Vessel_voxel_number, 1:2, sep=".")
    
     #Pixeldimension im Algorithmus = 1, jedoch in Wahrheit 0.065, daher Division der Radii durch 1/0.065
    #my_data$Corrected_vessel_radius <- as.numeric(my_data$Corrected_vessel_radius) / 15.38461538461538
    
    #group assignment
    if(str_detect(files[i], "maus_1/") == TRUE) {
      mouse <- "1"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_2/") == TRUE) {
      mouse <- "2"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_3/") == TRUE) {
      mouse <- "3"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_5/") == TRUE) {
      mouse <- "5"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_7/") == TRUE) {
      mouse <- "7"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_8/") == TRUE) {
      mouse <- "8"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_9/") == TRUE) {
      mouse <- "9"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_11/") == TRUE) {
      mouse <- "11"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_12/") == TRUE) {
      mouse <- "12"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_13/") == TRUE) {
      mouse <- "13"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_14/") == TRUE) {
      mouse <- "14"
      treatment <- "Sham"
    } else if(str_detect(files[i], "maus_15/") == TRUE) {
      mouse <- "15"
      treatment <- "ICAO"
    } else if(str_detect(files[i], "maus_16/") == TRUE) {
      mouse <- "16"
      treatment <- "ICAO"
    } else {
      mouse <- "17"
      treatment <- "Sham"
    } 
    
    #Hemisphere assignment
    if(str_detect(files[i], "Right") == TRUE) {
      side <- "Right"
    } else {
      side <- "Left"
    }
    
    #Connectivity level assignment
    if(str_detect(files[i], "3.txt") == TRUE) {
      threshold <- 3
    } else if(str_detect(files[i], "6.txt") == TRUE) {
      threshold <- 6
    } else {
      threshold <- 9
    }
  
    
    #data_frame
    Data <- data.frame(
      Mouse = as.character(mouse),
      Treatment = as.factor(treatment),
      Side = as.factor(side),
      Connectivity_threshold = as.factor(threshold),
      Vessel_voxel_number = as.numeric(my_data2$Vessel_voxel_number),
      Vessel_number = as.numeric(nrow(my_data)-2))

#Mean_vessel_radius = as.numeric(mean(my_data$Corrected_vessel_radius) rausgenommen
    
    #Saving results for each mice
    write_csv(Data,paste("data/r_clean/mouse",mouse,side,threshold,"results.csv", sep="_"))
}


#reading-in VOI files
files <- list.files(path="data/zurich_voi/VOI_size_fiji/", pattern="*.csv",full.names=TRUE, recursive=FALSE)
assignment <- read_xlsx("data/assignment.xlsx")

#function VOI measurements to clean data
VOI <- function(temp_results) {
  temp_results %>%
    mutate(X1=replace(X1,c(1:12),"Left"), X1=replace(X1,c(13:24),"Right"))%>%
    group_by(X1)%>%
    summarise(VOI_volume=sum(Area)*0.065)
}


#combining VOI measurements and group assignment
test_results <- map_dfr(lapply(files, read_csv), VOI)%>%
  bind_cols(assignment)%>%
  rename(Side = X1)

#get results file list
files2 <- list.files(path="data/r_clean/", pattern="*.csv",full.names=TRUE, recursive=FALSE)

#reading in zurich measurements
zurich_vessels <- map_dfr(files2, read_csv)

#combining zurich measurements with voi measurements
final <- zurich_vessels %>%
  inner_join(test_results, by=c("Mouse","Side"))%>%
  mutate(Vessel_volume = Vessel_voxel_number * 0.065 * 0.065 * 0.065, Vessel_volume_fraction = Vessel_volume/VOI_volume*100, Vessel_density = Vessel_number/VOI_volume)%>%
  filter(Side == "Right",Connectivity_threshold == 3)

final$Treatment <- as.factor(final$Treatment)

#plot vessel density between groups
ggplot(data=final, aes(x=Treatment, y=Vessel_density))+
  geom_boxplot(alpha=.1,outlier.shape = NA,width=.3,color="grey50")+
  geom_jitter(width=.1,size=2,color="black",alpha=.8)+
  scale_x_discrete(limits=c("Sham", "ICAO"))+
  ylab(expression(paste("MR vessel density [",mm^-3,"]")))+
  ggtitle("Vessel tracing analysis")+
  theme_classic()+
  theme(axis.line = element_line(),
        axis.title = element_text(color="black",size=12),
        axis.text = element_text(color="black",size=11),
        plot.title = element_text(hjust=.5),
        axis.title.x = element_blank())+
  annotate("text",y = 16 ,x=1.5,label = "P = 0.17",size=3.5)

#statistics vessel density
shapiro.test(final$Vessel_density)

t.test(final$Vessel_density~final$Treatment)

#plot correlation vessel density and vessel volume fraction
final <- zurich_vessels %>%
  inner_join(test_results, by=c("Mouse","Side"))%>%
  mutate(Vessel_volume = Vessel_voxel_number * 0.065 * 0.065 * 0.065, Vessel_volume_fraction = Vessel_volume/VOI_volume*100, Vessel_density = Vessel_number/VOI_volume)%>%
  filter(Connectivity_threshold == 3)

final$Treatment <- as.factor(final$Treatment)


ggplot(final, aes(x=Vessel_density, y=Vessel_volume_fraction))+
  geom_jitter(aes(color=Treatment),size=2,alpha=.9)+
  scale_color_manual(values = c("blue","red"),limits=c("Sham","ICAO"))+
  geom_smooth(method="lm", se=FALSE, color = "black")+
  ylab("MR vessel volume fraction [%]")+
  xlab(expression(paste("MR vessel density [",mm^-3,"]")))+
  annotate("text",y = 20,x=11.5,label = "r = -0.76, P = 0.000006",size=3.5)+
  ggtitle("Correlation")+
  theme_classic()+
  theme(axis.line = element_line(),
        axis.title = element_text(color="black",size=12),
        axis.text = element_text(color="black",size=11),
        plot.title = element_text(hjust=.5),
        legend.text = element_text(color="black",size=11))

#statistics
rho <- cor(final$Vessel_density, final$Vessel_volume_fraction, method="spearman")
CorCI(rho,n=28)
stats <- cor.test(final$Vessel_density, final$Vessel_volume_fraction, method="spearman")

stats$p.value
