library(tidyverse)
library(readxl)
library(BlandAltmanLeh)

data <- read_excel("images_isocortexNATIVE.xlsx",sheet="scores")%>%
  filter(image!="rc_rCBF.nii")%>%
  select(1,2,4,5)%>%
  spread(hemi,Mean)%>%
  mutate(right=right/both,left=left/both)%>%
  select(-both)%>%
  gather(hemi,mean,3:4)%>%
  spread(image,mean)%>%
  rename(ss_rCBV=3,dsc_rCBV=4)%>%
  mutate(diff=ss_rCBV-dsc_rCBV,avg=(ss_rCBV+dsc_rCBV)/2)

data <- data%>%
  summarise(diff=round(mean(diff),digits=7))

stats <- bland.altman.stats(data$ss_rCBV,data$dsc_rCBV)

ggplot(data,aes(x=avg,y=diff))+
  geom_point(color="black")+
  xlim(c(0.75,1.25))+
  ylim(c(-0.25,0.25))+
  geom_hline(yintercept=stats$lines[1],color="red",linetype=11)+
  geom_hline(yintercept=stats$lines[2],color="blue",linetype=11)+
  geom_hline(yintercept=stats$lines[3],color="red",linetype=11)+
  annotate("text",y=stats$lines[1]+0.02,x=1.2,label="-1.96 SD",color="red",size=3.5)+
  annotate("text",y=stats$lines[2]+0.02,x=1.2,label="Mean",color="blue",size=3.5)+
  annotate("text",y=stats$lines[3]+0.02,x=1.2,label="+1.96 SD",color="red",size=3.5)+
  labs(x="Average rCBV [AU]",y="Difference in rCBV [AU]")+
  theme_classic()+
  ggtitle("rCBV Bland-Altman plot")+
  theme(strip.background = element_blank(),
        strip.text = element_text(size = 10),
        axis.title = element_text(color="black",size=12),
        axis.text = element_text(color="black",size=11),
        axis.text.x = element_text(color="black"),
        axis.text.y = element_text(color="black"),
        plot.title = element_text(hjust = 0.5))

summary(stats)
