library(tidyverse)
library(readxl)

#group assignment
Group_assignment <- read_excel("groups.xlsx",col_names = TRUE)

roi <- c("Isocortex","withinBrainMask")

#rCBV
cbv_left <- read_excel("rCBV_labels_native_left_30Mar2019_19-36-37.xls", sheet = "mean", skip = 1)
cbv_right <- read_excel("rCBV_labels_native_right_30Mar2019_18-39-33.xls", sheet = "mean", skip = 1)

cbv_right_clean <-  cbv_right %>%
  rename(brain_region=1)%>%
  filter(str_detect(brain_region,paste(roi,collapse="|")))%>%
  slice(1:2)%>%
  gather(Mouse, "ss_CBV_right", 2:15)%>%
  spread(brain_region,ss_CBV_right)%>%
  inner_join(Group_assignment, by="Mouse")%>%
  rename(control_r=2,isocortex_r=3)

cbv_left_clean <-  cbv_left%>%
  rename(brain_region=1)%>%
  filter(str_detect(brain_region,paste(roi,collapse="|")))%>%
  slice(1:2)%>%
  gather(Mouse, "ss_CBV_left", 2:15)%>%
  spread(brain_region,ss_CBV_left)%>%
  inner_join(Group_assignment, by="Mouse")%>%
  rename(control_l=2,isocortex_l=3)

combined <- inner_join(cbv_right_clean,cbv_left_clean)%>%
  select(1,4,2,3,5,6)%>%
  mutate(isocortex_rn=isocortex_r/control_l)%>%
  select(Mouse,Treatment,isocortex_rn)

#####
t.test(combined$isocortex_rn~combined$Treatment)

combined_sd <- combined%>%
  group_by(Treatment)%>%
  summarise(mean=mean(isocortex_rn),sds = sd(isocortex_rn))

ggplot(combined,aes(x=Treatment,y=isocortex_rn))+
  geom_boxplot(alpha=.1,outlier.shape = NA,width=.3,color="grey50")+
  geom_jitter(width=.1,size=2,color="black",alpha=.8)+
  ylab("DSC-rCBV [AU]")+
  xlab("Treatment")+
  scale_x_discrete(limits=c("Sham", "ICAO"), labels=c("Sham" = "Sham", "ICAO" = "ICAO"))+
  theme_classic()+
  ggtitle("DSC-rCBV analysis")+
  theme(axis.line = element_line(),
        axis.title = element_text(color="black",size=12),
        axis.text = element_text(color="black",size=11),
        plot.title = element_text(hjust=.5),
        axis.title.x = element_blank())+
  annotate("text",y = 1.3,x=1.5,label = "P = 0.000002",size=3.5)
