##STP
library(tidyverse)
library(readxl)
library(correlation)

TV_raw <- read_excel("data/#res_corrTV_BVf.xls", 
                     sheet = "dat_median_vol>=1qmm")

TV_clean <- TV_raw%>%
  mutate(number=row_number())%>%
  gather("modality","value",1:6)%>%
  separate(2,c("modality","mouse"),sep="_")%>%
  spread(modality,value)%>%
  mutate(mouse=str_replace(mouse,"M15","ICAO 1"),
         mouse=str_replace(mouse,"M16","ICAO 2"),
         mouse=str_replace(mouse,"M17", "Sham 1"))%>%
  na.omit()

cor(TV_clean$BVf,TV_clean$TV,method="spearman")

summary(cor(TV_clean$BVf,TV_clean$TV,method="spearman"))

ggplot(data=TV_clean,aes(x=TV,y=BVf,color=mouse))+
  geom_point(alpha=.4)+
  geom_smooth(method="lm",se=FALSE)+
  coord_fixed()+
  ylab("ss-CBV [%]")+
  xlab("STP-CBV [%]")+
  theme_classic()+
  ggtitle("Correlation")+
  theme(axis.line = element_line(),
        axis.title = element_text(color="black",size=12),
        axis.text = element_text(color="black",size=11),
        plot.title = element_text(hjust=.5),
        legend.title = element_blank())+
  annotate("text",y = 6,x=3,label = "Mean r = 0.57, P < 0.000001",size=3.5)
